==> 0.1.0.tar.gz: test/dsl.dart <==
// Copyright (c) 2012, Ladislav Thon. All rights reserved. Use of this source
// code is governed by a BSD-style license that can be found in the LICENSE file.

import 'package:darmatch/matchers.dart';
import 'package:detester/detester.dart';
import 'package:detester/dsl.dart';

part 'package:detester/test.dart';

suite() => [
  testTable,
  testTransformedTable,
  testExpect,
  testExpectWithDescription,
  testExpectFromData,
  testExpectFromDataWithDescription,
  testExpectFromDataTable,
  testExpectFromEachData,
  testExpectFromEachDataWithDescription,
  testExpectFromEachDataTable
];

testTable() {
  var t = table * "Column 1" * "Column 2"
                | 1          | "a"
                | 2          | "b"
                | 3          | "c"
                ;

  var list = new List.from(t);
  expectThat(list, collectionLength(equals(3)));
  expectThat(list[0], collectionLength(equals(2)));
  expectThat(list[0][0], equals(1));
  expectThat(list[0][1], equals("a"));
  expectThat(list[1], collectionLength(equals(2)));
  expectThat(list[1][0], equals(2));
  expectThat(list[1][1], equals("b"));
  expectThat(list[2], collectionLength(equals(2)));
  expectThat(list[2][0], equals(3));
  expectThat(list[2][1], equals("c"));
}

class Foo {
  final int bar;
  final String baz;

  Foo(this.bar, this.baz);

  bool operator==(other) => other is Foo
      && bar == other.bar
      && baz == other.baz;
}

testTransformedTable() {
  var asFoo = (row) => new Foo(row[0], row[1]);

  var t = table * "Column 1" * "Column 2" > asFoo
                | 1          | "a"
                | 2          | "b"
                | 3          | "c"
                ;

  expectThat(t, orderedEquals([
      new Foo(1, "a"),
      new Foo(2, "b"),
      new Foo(3, "c")
  ]));
}

testExpect() {
  expectThat(
      () {
        expect
          * (1 + 1 == 2)
          * (() => 2 + 2 == 4)
          ;
      },
      returnsNormally()
  );

  expectThat(
      () {
        expect
          * (1 + 1 == 3)
          * (() => 2 + 2 == 5)
          ;
      },
      throws(caught: new IsType<ExpectException>())
  );
}

testExpectWithDescription() {
  expectThat(
      () {
        expect
          * "1 + 1 = 2" / (1 + 1 == 2)
          * "2 + 2 = 4" / (() => 2 + 2 == 4)
          ;
      },
      returnsNormally()
  );

  expectThat(
      () {
        expect
          * "1 + 1 = 3" / (1 + 1 == 3)
          * "2 + 2 = 5" / (() => 2 + 2 == 5)
          ;
      },
      throws(caught: new IsType<ExpectException>())
  );
}

testExpectFromData() {
  expectThat(
      () {
        expect
          * isNotNull()
          * isTrue()
          * not(isFalse())
          < true;
      },
      returnsNormally()
  );

  expectThat(
      () {
        expect
          * isNull()
          * isFalse()
          * not(isTrue())
          < true;
      },
      throws(caught: new IsType<ExpectException>())
  );
}

testExpectFromDataWithDescription() {
  expectThat(
      () {
        expect
          * "it isn't null" / isNotNull()
          * "it is true" / isTrue()
          * "it isn't false" / not(isFalse())
          < true;
      },
      returnsNormally()
  );

  expectThat(
      () {
        expect
          * "it is null" / isNull()
          * "it is false" / isFalse()
          * "it isn't true" / not(isTrue())
          < true;
      },
      throws(caught: new IsType<ExpectException>())
  );
}

testExpectFromDataTable() {
  expectThat(
      () {
        var t = table * "Column 1" * "Column 2"
                      | 1          | "a"
                      | 2          | "b"
                      | 3          | "c"
                      ;

        expect
          * isNotNull()
          * "it is iterable" / new IsType<Iterable>()
          < t;
      },
      returnsNormally()
  );

  expectThat(
      () {
        var t = table * "Column 1" * "Column 2"
                      | 1          | "a"
                      | 2          | "b"
                      | 3          | "c"
                      ;

        expect
          * isNull()
          * "it is not iterable" / not(new IsType<Iterable>())
          < t;
      },
      throws(caught: new IsType<ExpectException>())
  );
}

testExpectFromEachData() {
  expectThat(
      () {
         expect
          * isNotNull()
          * new IsType<int>()
          * positive()
          * even()
          * ((it) => it > 1 && it < 33)
          < each([2, 4, 8, 16, 32]);
      },
      returnsNormally()
  );
}

testExpectFromEachDataWithDescription() {
  expectThat(
      () {
         expect
          * "it isn't null" / isNotNull()
          * "it is an int" / new IsType<int>()
          * "it is positive" / positive()
          * "it is even" / even()
          * "it is > 1 and < 33" / ((it) => it > 1 && it < 33)
          < each([2, 4, 8, 16, 32]);
      },
      returnsNormally()
  );
}

testExpectFromEachDataTable() {
  expectThat(
      () {
        var t = table * "String" * "Length"
                      | "Foo"    | 3
                      | "Bar"    | 3
                      | "Baz"    | 3
                      | "Qux"    | 3
                      | "Quux"   | 4
                      | "Corge"  | 5
                      | "Grault" | 6
                      | "Garply" | 6
                      | "Waldo"  | 5
                      | "Fred"   | 4
                      | "Plugh"  | 5
                      | "Xyzzy"  | 5
                      | "Thud"   | 4
                      ;
        expect
          * "it isn't null" / isNotNull()
          * "it is Iterable" / new IsType<Iterable>()
          * "but it isn't a Collection" / not(new IsType<Collection>())
          * "neither a List, obviously" / not(new IsType<List>())
          * "but it has length" / ((it) => it.length == 2)
          * "string has defined length" / ((it) => it[0].length == it[1])
          * "string has defined length" / ((it) => it["String"].length == it["Length"])
          * "string has defined length" / ((it) => it.String.length == it.Length)
          < each(t);
      },
      returnsNormally()
  );
}

==> 0.2.0.tar.gz: test/dsl.dart <==
// Copyright (c) 2012, Ladislav Thon. All rights reserved. Use of this source
// code is governed by a BSD-style license that can be found in the LICENSE file.

import 'package:darmatch/matchers.dart';
import 'package:detester/dsl.dart';

import 'package:detester/console.dart';
part 'package:detester/console_test.dart';

suite() => [
  testTable,
  testTransformedTable,
  testExpect,
  testExpectWithDescription,
  testExpectFromData,
  testExpectFromDataWithDescription,
  testExpectFromDataTable,
  testExpectFromEachData,
  testExpectFromEachDataWithDescription,
  testExpectFromEachDataTable
];

testTable() {
  var t = table * "Column 1" * "Column 2"
                | 1          | "a"
                | 2          | "b"
                | 3          | "c"
                ;

  // just for running in checked mode -- row in table isn't real Iterable
  var list = new List.from(t);
  var list0 = new List.from(list[0]);
  var list1 = new List.from(list[1]);
  var list2 = new List.from(list[2]);

  expectThat(list, iterableLength(equals(3)));
  expectThat(list0, iterableLength(equals(2)));
  expectThat(list0[0], equals(1));
  expectThat(list0[1], equals("a"));
  expectThat(list1, iterableLength(equals(2)));
  expectThat(list1[0], equals(2));
  expectThat(list1[1], equals("b"));
  expectThat(list2, iterableLength(equals(2)));
  expectThat(list2[0], equals(3));
  expectThat(list2[1], equals("c"));
}

class Foo {
  final int bar;
  final String baz;

  Foo(this.bar, this.baz);

  bool operator==(other) => other is Foo
      && bar == other.bar
      && baz == other.baz;
}

testTransformedTable() {
  var asFoo = (row) => new Foo(row[0], row[1]);

  var t = table * "Column 1" * "Column 2" > asFoo
                | 1          | "a"
                | 2          | "b"
                | 3          | "c"
                ;

  expectThat(t, orderedEquals([
      new Foo(1, "a"),
      new Foo(2, "b"),
      new Foo(3, "c")
  ]));
}

testExpect() {
  expectThat(
      () {
        expect
          * (1 + 1 == 2)
          * (() => 2 + 2 == 4)
          ;
      },
      returnsNormally()
  );

  expectThat(
      () {
        expect
          * (1 + 1 == 3)
          * (() => 2 + 2 == 5)
          ;
      },
      throws(new IsType<ExpectationFailedException>())
  );
}

testExpectWithDescription() {
  expectThat(
      () {
        expect
          * "1 + 1 = 2" / (1 + 1 == 2)
          * "2 + 2 = 4" / (() => 2 + 2 == 4)
          ;
      },
      returnsNormally()
  );

  expectThat(
      () {
        expect
          * "1 + 1 = 3" / (1 + 1 == 3)
          * "2 + 2 = 5" / (() => 2 + 2 == 5)
          ;
      },
      throws(new IsType<ExpectationFailedException>())
  );
}

testExpectFromData() {
  expectThat(
      () {
        expect
          * isNotNull()
          * isTrue()
          * not(isFalse())
          < true;
      },
      returnsNormally()
  );

  expectThat(
      () {
        expect
          * isNull()
          * isFalse()
          * not(isTrue())
          < true;
      },
      throws(new IsType<ExpectationFailedException>())
  );
}

testExpectFromDataWithDescription() {
  expectThat(
      () {
        expect
          * "it isn't null" / isNotNull()
          * "it is true" / isTrue()
          * "it isn't false" / not(isFalse())
          < true;
      },
      returnsNormally()
  );

  expectThat(
      () {
        expect
          * "it is null" / isNull()
          * "it is false" / isFalse()
          * "it isn't true" / not(isTrue())
          < true;
      },
      throws(new IsType<ExpectationFailedException>())
  );
}

testExpectFromDataTable() {
  expectThat(
      () {
        var t = table * "Column 1" * "Column 2"
                      | 1          | "a"
                      | 2          | "b"
                      | 3          | "c"
                      ;

        expect
          * isNotNull()
          * "it is iterable" / new IsType<Iterable>()
          < t;
      },
      returnsNormally()
  );

  expectThat(
      () {
        var t = table * "Column 1" * "Column 2"
                      | 1          | "a"
                      | 2          | "b"
                      | 3          | "c"
                      ;

        expect
          * isNull()
          * "it is not iterable" / not(new IsType<Iterable>())
          < t;
      },
      throws(new IsType<ExpectationFailedException>())
  );
}

testExpectFromEachData() {
  expectThat(
      () {
         expect
          * isNotNull()
          * new IsType<int>()
          * positive()
          * even()
          * ((it) => it > 1 && it < 33)
          < each([2, 4, 8, 16, 32]);
      },
      returnsNormally()
  );
}

testExpectFromEachDataWithDescription() {
  expectThat(
      () {
         expect
          * "it isn't null" / isNotNull()
          * "it is an int" / new IsType<int>()
          * "it is positive" / positive()
          * "it is even" / even()
          * "it is > 1 and < 33" / ((it) => it > 1 && it < 33)
          < each([2, 4, 8, 16, 32]);
      },
      returnsNormally()
  );
}

testExpectFromEachDataTable() {
  expectThat(
      () {
        var t = table * "String" * "Length"
                      | "Foo"    | 3
                      | "Bar"    | 3
                      | "Baz"    | 3
                      | "Qux"    | 3
                      | "Quux"   | 4
                      | "Corge"  | 5
                      | "Grault" | 6
                      | "Garply" | 6
                      | "Waldo"  | 5
                      | "Fred"   | 4
                      | "Plugh"  | 5
                      | "Xyzzy"  | 5
                      | "Thud"   | 4
                      ;
        expect
          * "it isn't null" / isNotNull()
          * "it is Iterable" / new IsType<Iterable>()
          * "but it isn't a Collection" / not(new IsType<Collection>())
          * "neither a List, obviously" / not(new IsType<List>())
          * "but it has length" / ((it) => it.length == 2)
          * "string has defined length" / ((it) => it[0].length == it[1])
          * "string has defined length" / ((it) => it["String"].length == it["Length"])
          * "string has defined length" / ((it) => it.String.length == it.Length)
          < each(t);
      },
      returnsNormally()
  );
}
